@@ -22,7 +22,7 @@ impl layeredconf::LayeredConfLayer for TestLayer {
     }
 }
 impl TestLayer {
-    pub fn empty(&self) -> bool {
+    fn empty(&self) -> bool {
         let mut empty = vec![];
         empty.push(self.boolean.is_none());
         empty.push(self.integer.is_none());
